function [output, header_row] = read_ser(filename, runname)

% READ_SER Function for reading .ser files from Sicopolis.  
% Patrick Applegate, patrick.applegate@natgeo.su.se, 1 Mar 2010
% 
% (header_row, output) = read_ser(filename)
% header_row, list of variables in output columns
% output, list of variable values arranged in columns
% filename, name of .ser file to read (must be enclosed in single quotes)
% runname, name of run (same as RUNNAME in header file)

% Read in the .ser file as the matrix raw_data.  
raw_data = dlmread(filename, '', 4, 0); 

% After using this command, the matrix data will have six columns and a 
% number of rows equal to three times the number of output time steps 
% involved in the run.  Each set of three rows contains the variables 
% related to one output time step.  The arrangement of variables within 
% these three-row sets is as follows.  
% 
% t(ka)  		D_Ts(deg C)     z_sl(m)         (none)          (none)          (none)
% H_max(km)   	zs_max(km)      V_g(10^6km3) 	V_t(10^3km3)  	V_fw(km3/a)     z_sle(m)
% Aib(10^6km2) 	Atb(10^6km2)  	V_bm(km3/a) 	V_tld(km3/a)   	H_t_max(m)  	vs_max(m/a)
% 
% The row and column in raw_data where the first value for each variable 
% appears is
% 
% 1. t = raw_data(1, 1)         ka; elapsed time
% 2. D_Ts = raw_data(1, 2)		deg. C; surface temperature anomaly (forcing)
% 3. z_sl = raw_data(1, 3)		m; sea level (forcing)
% 
% 4. H_max = raw_data(2, 1)		m; maximum ice thickness
% 5. zs_max = raw_data(2, 2)	m; maximum ice elevation
% 6. V_g = raw_data(2, 3)		10^ 6 km^ 3; total ice volume (note units!)
% 7. V_t = raw_data(2, 4)		km^ 3; volume of temperate ice (note units!)
% 8. V_fw = raw_data(2, 5)		km^ 3/ yr; volume of freshwater produced by melting and calving
% 9. z_sle = raw_data(2, 6)		m; sea level equivalent of ice volume (on land?)  
% 
% 10. Aib = raw_data(3, 1)		10^ 6 km^ 2; ice-covered area
% 11. Atb = raw_data(3, 2)		10^ 6 km^ 2; area covered by temperate ice
% 12. V_bm = raw_data(3, 3)		km^ 3/ yr; water drainage due to basal melting
% 13. V_tld = raw_data(3, 4)	km^ 3/ yr; water drainage from the temperate ice
% 14. H_t_max = raw_data(3, 5)	m; maximum thickness of the temperate ice
% 15. vs_max = raw_data(3, 6)	m/ yr; maximum surface velocity
% 
% The numbers also indicate the columns in which each variable is stored in
% the eventual output.  

% Set up a matrix in which each row represents the indices in raw_data of
% the first occurrence of one variable.  That is, top_value(3, :) yields
% the indices of the first entry corresponding to variable 3, z_sl.  
top_value = [1, 1; 1, 2; 1, 3; 2, 1; 2, 2; 2, 3; 2, 4; ...
             2, 5; 2, 6; 3, 1; 3, 2; 3, 3; 3, 4; 3, 5; 3, 6]; 

% Determine the number of output time steps in the .ser file.  
num_steps = (size(raw_data, 1)/ 3); 

% Perform the conversion.  
output = zeros(num_steps, 6); 
for count1 = 1: 1: num_steps; 
    row_inc = 3* (count1- 1); 
    index(1: 15, 1) = top_value(:, 1)+ row_inc; 
    index(1: 15, 2) = top_value(:, 2);
    for count2 = 1: 1: 15; 
        output(count1, count2) = ...
            raw_data(index(count2, 1), index(count2, 2)); 
    end
end

% Write the variable names to the vector header_row.  
header_row = {'t(ka)', 'D_Ts(deg C)', 'z_sl(m)', 'H_max(km)', ...
    'zs_max(km)', 'V_g(10^6km3)', 'V_t(10^3km3)', 'V_fw(km3/a)', ...
    'z_sle(m)', 'Aib(10^6km2)', 'Atb(10^6km2)', 'V_bm(km3/a)', ...
    'V_tld(km3/a)', 'H_t_max(m)', 'vs_max(m/a)'}; 

% Write the output to portable formats.  Note that the .csv file does not
% contain header_row.  
% csvwrite([runname, '_series.csv'], output)
% save([runname, '_series.mat'], 'header_row', 'output')